pub enum CacheProfile {
Static,
Dynamic,
Custom {
entry_timeout_secs: u64,
attr_timeout_secs: u64,
},
}Expand description
Cache profile for a VirtioFS share.
Controls the FUSE entry and attribute cache timeouts reported to the guest kernel. Higher values reduce FUSE round-trips at the cost of delayed visibility of host filesystem changes.
Variants
Static
Static content (runtime binaries, container images). Entry/attr timeout: 300s. Aggressive caching.
Dynamic
Dynamic content (user source files). Entry/attr timeout: 1s. Minimal caching.
Custom
Custom timeout values.
Implementations
Sourceimpl CacheProfile
impl CacheProfile
Sourcepub fn entry_timeout(&self) -> Duration
pub fn entry_timeout(&self) -> Duration
Returns the entry timeout for FUSE responses.
Sourcepub fn attr_timeout(&self) -> Duration
pub fn attr_timeout(&self) -> Duration
Returns the attr timeout for FUSE responses.